@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 # coding:utf-8
 
 from argparse import Namespace
@@ -257,19 +256,14 @@ class commands:
         sys.stderr.flush()
 
     def __add_optional_version(self, argp: argp):
-
-        if not isinstance(self.version, str):
-            return
-
-        version = self.version.strip()
-        if not version:
+        version = self.version
+        if not isinstance(version, str):
             return
 
         options = argp.filter_optional_name("-v", "--version")
         if len(options) > 0:
-            argp.add_argument(*options,
-                              action="version",
-                              version=f"%(prog)s {version}")
+            argp.add_argument(*options, action="version",
+                              version=f"%(prog)s {version.strip()}")
 
     def __add_inner_parser_tail(self, argp: argp):
 
@@ -400,9 +394,10 @@ class commands:
         if hasattr(args, "_log_console_") and args._log_console_ is not None:
             addHandler(logging.StreamHandler(stream=args._log_console_))
 
-        for filename in args._log_files_:
-            assert isinstance(filename, str)
-            addHandler(logging.FileHandler(filename))
+        if hasattr(args, "_log_files_"):
+            for filename in args._log_files_:
+                assert isinstance(filename, str)
+                addHandler(logging.FileHandler(filename))
 
     def __add_parser(self, _map: Dict[add_command, argp],
                      arg_root: argp, cmd_root: add_command, **kwargs):
@@ -438,7 +433,7 @@ class commands:
         assert isinstance(root, add_command)
 
         _map: Dict[add_command, argp] = dict()
-        _arg = argp(**kwargs)
+        _arg = argp(argv=argv, **kwargs)
         self.__prog = _arg.prog
         self.__add_optional_version(_arg)
         # To support preparse_from_sys_argv(), all subparsers must be added
@@ -453,34 +448,21 @@ class commands:
         return self.args
 
     def __run(self, args: Namespace, root: add_command) -> int:
-        if not isinstance(root, add_command):
-            return ENOENT
-
-        if not isinstance(root.bind, run_command):
-            return ENOENT
+        assert isinstance(root, add_command)
+        assert isinstance(root.bind, run_command)
 
         ret = root.bind.func(self)
         if ret != 0 and ret is not None:
             return ret
 
         if hasattr(args, root.sub_dest):
-
-            sub_name = getattr(args, root.sub_dest)
-            if isinstance(sub_name, str):
-
-                subs = root.subs
-                if not (isinstance(subs, list) or isinstance(subs, tuple)):
-                    return ENOENT
-
-                for sub in subs:
-                    if not isinstance(sub, add_command):
-                        continue
-
-                    if sub.name == sub_name:
+            sub_dest = getattr(args, root.sub_dest)
+            if isinstance(sub_dest, str):
+                assert isinstance(root.subs, (list, tuple))
+                for sub in root.subs:
+                    assert isinstance(sub, add_command)
+                    if sub.name == sub_dest:
                         return self.__run(args, sub)
-
-                return ENOENT
-
         return 0
 
     def run(self,
