@@ -1,4 +1,3 @@
-#!/usr/bin/python3
 # coding=utf-8
 
 
@@ -8,7 +7,7 @@ from typing import List
 __package_name__ = "xarg-python"
 __prog_name__ = "xarg"
 __prog_complete__ = "xargcomplete"
-__version__ = "1.1"
+__version__ = "1.2"
 
 URL_PROG = "https://github.com/bondbox/xarg-python"
 
@@ -33,10 +32,6 @@ class chdir:
     def __init__(self):
         self.__stack: List[str] = []
 
-    def __del__(self):
-        if len(self.__stack) > 0:
-            os.chdir(self.__stack[0])
-
     def pushd(self, path: str):
         '''
         Add directory to stack.
